@@ -4,16 +4,16 @@ import pickle
 import itertools 
 from shutil import copyfile
 
-# from .file_operations import __read_from_file, __write_to_file
-# from .convert_annotations import __convert_annotations_opencv_to_yolo, __convert_annotations_yolo_to_opencv
-# from .other_fuctions import __run_shell_command
-# from .cfg_templates import __get_cfg_template
+from .file_operations import __read_from_file, __write_to_file
+from .convert_annotations import __convert_annotations_opencv_to_yolo, __convert_annotations_yolo_to_opencv
+from .other_fuctions import __run_shell_command
+from .cfg_templates import __get_cfg_template
 
 
-from file_operations import __read_from_file, __write_to_file
-from convert_annotations import __convert_annotations_opencv_to_yolo, __convert_annotations_yolo_to_opencv
-from other_fuctions import __run_shell_command
-from cfg_templates import __get_cfg_template
+# from file_operations import __read_from_file, __write_to_file
+# from convert_annotations import __convert_annotations_opencv_to_yolo, __convert_annotations_yolo_to_opencv
+# from other_fuctions import __run_shell_command
+# from cfg_templates import __get_cfg_template
 
  
 
